/* $Workfile: OtxBri.h $   $Revision: 15 $    $Modtime: 8/06/04 2:56p $  */
#ifndef OTX_BRI_H
#define OTX_BRI_H
/******************************************************************************

  @doc PublicHwApi OtxBri

  Copyright (C) 1998 - 2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxBri | This file contains prototypes for the ISDN BRI Line Interface Functions

  @contents2
  OtxBri.h |

  @index func | OtxBri

  @contents2
  OTX ISDN BRI Line Interface Device Functions - OtxBriXXX() | The user functions available for
  the Analog Phone Line Interface Decivces following;

  @head3 OtxBriXXX() Function Reference |

  @index func | OtxBri

******************************************************************************/

#include "OtxDef.h"     // OTX specific definitions

#include "OtxBriD.h"    // OTX POTS type definitions

#ifdef __cplusplus
extern "C" {
#endif


/******************************************************************************

  @func

    Sets up the BRI Line Interface transceiver in either Terminal (TE)
    or Network (NT) mode.

  @xref
    <t OtxBriLiModeE>

******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxBriSetLiMode(
  IN OTX_HANDLE     hBriDev,          // @parm Handle to the BRI Device
  IN OtxBriLiModeE  eLiMode           // @parm Mode to be configured to (TE/NT)
);


/******************************************************************************

  @func

    Sets up a pair of Line Interfaces to operate in monitor mode. The
    first Li will listen as a TE. The second Li will listen as an NT.

******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxBriConfigureMonitor(
  IN OTX_HANDLE     hBriTeDev,        // @parm Handle to the the Li which will listen as a TE
  IN OTX_HANDLE     hBriNtDev         // @parm Handle to the the Li which will listen as a NT
);


/******************************************************************************

  @func

    Read the physical line status of the T1/E1 Line Interface.

******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxBriGetLineStatus(
  IN OTX_HANDLE     hBriDev,          // @parm Handle to the BRI Transceiver Device
  OUT OTX_UINT32    *pLineStatus      // @parm T1/E1 Physical Layer Line Status
);


/******************************************************************************

  @func

    Issues a Layer 1 Activate Request.

******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxBriActivateLink(
  IN OTX_HANDLE     hBriDev,          // @parm Handle to the BRI Transceiver Device
  IN OTX_TIME       nWaitMaxMs        // @parm Time in milliseconds to wait for the layer 1 to become active
);


/******************************************************************************

  @func

    Issues a Layer 1 Deactivate Request.

  @comm

    Only meaninful if the Li is configured in LT_S (NT) mode.

******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxBriDeactivateLink(
  IN OTX_HANDLE     hBriDev,          // @parm Handle to the BRI Transceiver Device
  IN OTX_TIME       nWaitMaxMs        // @parm Time in milliseconds to wait for the layer 1 to become active
);


/******************************************************************************

  @func

    Connects or disconnects the BRI S-Interface 100-ohm terminating resistor
    for a specified Line Interface.

******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxBriTermLi(
  IN OTX_HANDLE     hBriDev,          // @parm Handle to the BRI Transceiver Device
  IN OTX_BOOL       bConnectTermRes   // @parm If OTX_TRUE, connect the terminating resistor
);


#ifdef __cplusplus
}  // extern "C"
#endif

/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998 - 2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/

#endif    // OTX_BRI_H
